@@ -6,15 +6,13 @@
 ####################################################
 
 use Hardware::Vhdl::Hierarchy;
-$parse = new Hardware::Vhdl::Hierarchy;
+$parser = new Hardware::Vhdl::Hierarchy;
 
 # $::RD_TRACE = 1;
 $::RD_WARN = undef;
 $::RD_HINT = undef;
 
-my @file = <>;
-my $file = join('',@file);
-$parse->design_file($file);
+$parser->Filename(@ARGV);
 
 
 
